@@ -10,21 +10,15 @@ import tensorflow as tf
 sys.path.append("..")
 
 # Import utilites
-from utils_extractor import label_map_util
-from utils_extractor import visualization_utils as vis_util
-
-# Name of the directory containing the object detection module we're using
-MODEL_NAME = 'model'
-
-# Grab path to current working directory
-CWD_PATH = os.getcwd()
+from id_card_extractor.utils_extractor import label_map_util
+from id_card_extractor.utils_extractor import visualization_utils as vis_util
 
 # Path to frozen detection graph .pb file, which contains the model that is used
 # for object detection.
-PATH_TO_CKPT = os.path.join(CWD_PATH, MODEL_NAME, 'frozen_inference_graph.pb')
+PATH_TO_CKPT = os.path.dirname(os.path.realpath(__file__)) + '/model/frozen_inference_graph.pb'
 
 # Path to label map file
-PATH_TO_LABELS = os.path.join(CWD_PATH, 'data', 'labelmap.pbtxt')
+PATH_TO_LABELS = os.path.dirname(os.path.realpath(__file__)) + '/data/labelmap.pbtxt'
 
 # Number of classes the object detector can identify
 NUM_CLASSES = 1
@@ -100,7 +94,7 @@ def get_card_from_image(image):
     ymin, xmin, ymax, xmax = array_coord
     shape = np.shape(image1)
     im_width, im_height = shape[1], shape[0]
-    (left, right, top, bottom) = (xmin * im_width, xmax * im_width, ymin * im_height, ymax * im_height)
+    (left, right, top, bottom) = (xmin * 0.5 * im_width, xmax * im_width * 1.25, ymin * im_height * 0.75, ymax * im_height * 1.15)
 
     if ymin == xmax == xmin == ymax == 0:
         return {
